/*
 *  ----------------------------------------------------------------------------
 *  Filename      : GuiFactory.java
 *  ----------------------------------------------------------------------------
 *  Application   : Soekia
 *  Author        : Matthias Dreier
 *  File created  : 11.09.2003
 *  ----------------------------------------------------------------------------
 *  This file is part of Soekia.
 *
 *  Soekia is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Soekia is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Soekia; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  ----------------------------------------------------------------------------
 */
package ch.educeth.soekia;

import java.awt.Color;
import java.awt.Component;
import java.awt.Cursor;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.LayoutManager;
import java.awt.RenderingHints;
import java.awt.event.ActionListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.ButtonGroup;
import javax.swing.JComponent;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JRadioButton;

import ch.educeth.soekia.util.StringConstants;

/**
 * GuiFactory.
 *
 * @author	Matthias Dreier
 */
public class GuiFactory {

	/**
	 * The color of the background.
	 */
	public Color backgroundColor = Color.white;

	/**
	 * The color of the title.
	 */
	public Color titleColor = new Color(127, 127, 255);

	/**
	 * The HelpPanel.
	 */
	protected HelpPanel helpPanel;

	/**
	 * Creates a new JFrame for the given title and component.
	 *
	 * @param	title		The title of the frame.
	 * @param	component	The component for the frame.
	 * @return				A new JFrame.
	 */
	public JFrame createJFrame(String title, JComponent component) {
		JFrame frame = new JFrame(title);
		frame.getContentPane().add(component);
		frame.setIconImage(Application.getIcon(StringConstants.getString(StringConstants.ICON_FILE)).getImage());

		return frame;
	}

	/**
	 * Creates a new JPanel.
	 *
	 * @return		A new JPanel.
	 */
	public JPanel createJPanel() {
		JPanel panel = new JPanel();
		panel.setBackground(backgroundColor);

		return panel;
	}

	/**
	 * Creates a new JPanel for the given layout manager.
	 *
	 * @param	layoutManager	The layout manager.
	 *
	 * @return					A new JPanel.
	 */
	public JPanel createJPanel(LayoutManager layoutManager) {
		JPanel panel = new JPanel(layoutManager);
		panel.setBackground(backgroundColor);

		return panel;
	}

	/**
	 * Creates a new JRadioButton for the given ButtonGroup.
	 *
	 * @param	bg				The ButtonGroup.
	 * @param	selected		Whether the button is selected.
	 * @param	actionCommand	The action command.
	 * @param	actionListener	The action listener.
	 *
	 * @return					A new JRadioButton for the given ButtonGroup.
	 */
	public JRadioButton createJRadioButton(ButtonGroup bg, boolean selected, String actionCommand, ActionListener actionListener) {
		JRadioButton radioButton = new JRadioButton("", selected);
		radioButton.setActionCommand(actionCommand);
		radioButton.setAlignmentX(Component.CENTER_ALIGNMENT);
		radioButton.setBackground(backgroundColor);
		radioButton.addActionListener(actionListener);
		bg.add(radioButton);

		return radioButton;
	}

	/**
	 * Creates a new link label for the given text.
	 *
	 * @param	text		The text for the label.
	 * @param	tooltip		The tooltip for the label.
	 * @param	title		The title for the message dialog.
	 *
	 * @return				A new link label for the given text.
	 */
	public JLabel createLinkLabel(String text, String tooltip, final String title) {
		JLabel linkLabel = new JLabel(text);
		linkLabel.addMouseListener(new MouseAdapter() {
			public void mouseClicked(MouseEvent e) {
				JOptionPane.showMessageDialog(null, ((JLabel)e.getSource()).getToolTipText(), title, JOptionPane.INFORMATION_MESSAGE);
			}
		});
		linkLabel.setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
		linkLabel.setToolTipText(tooltip);

		return linkLabel;
	}

	/**
	 * Creates a new label for the given text.
	 *
	 * @param	text	The text for the label.
	 *
	 * @return			A new label for the given text.
	 */
	public JLabel createTitleLabel(String text) {
		JLabel titleLabel = new JLabel(text) {
			public void paint(Graphics g) {
				((Graphics2D)g).addRenderingHints(new RenderingHints(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON));
				super.paint(g);
			}
		};
		titleLabel.setFont(new Font("Dialog", Font.PLAIN, 18));
		titleLabel.setForeground(titleColor);

		return titleLabel;
	}

	/**
	 * Returns a HelpPanel.
	 *
	 * @return		A HelpPanel.
	 */
	public JPanel createHelpPanel() {
		if (helpPanel == null) {
			helpPanel = new HelpPanel(backgroundColor, Color.blue);
			helpPanel.addPage(StringConstants.getString(StringConstants.SOEKIA_LABEL), "ch/educeth/soekia/resources/" + StringConstants.getString(StringConstants.SOEKIA_HELP_FILE));
			helpPanel.addPage(StringConstants.getString(StringConstants.USER_INTERFACE_LABEL), "ch/educeth/soekia/resources/" + StringConstants.getString(StringConstants.USER_INTERFACE_HELP_FILE));
			helpPanel.addPage(StringConstants.getString(StringConstants.GPL_LABEL), "ch/educeth/soekia/resources/" + StringConstants.getString(StringConstants.GPL_FILE));
			helpPanel.showPage(StringConstants.getString(StringConstants.SOEKIA_LABEL));
		}

		return helpPanel;
	}

}
